@@ -8,8 +8,8 @@
     timedep0,nbinnerknots0,qorder0,filtretps0,BetaTpsMat,EPS,nbgh,familyrisk) ! rajout
 
 
-!
-! Obs: noVar=0 indicates no variables but I need to pass all 0's in vaxAux
+    !
+    ! Obs: noVar=0 indicates no variables but I need to pass all 0's in vaxAux
     use parameters
     use tailles
     use comon
@@ -35,7 +35,9 @@
     double precision,dimension(3*nsujetAux)::aux
     double precision,dimension(np*(np+3)/2)::v
     double precision,dimension(np)::b
-    double precision,dimension(np,np)::HIH,IH,HI
+    double precision,dimension(np,np)::HIH,IH,HI  
+    double precision,dimension(:,:),allocatable::HIH_temp,IH_temp
+    !double precision,dimension(npmax,npmax)::HIH,IH,HI
     !******************************************   Add JRG January 05
     
     double precision,dimension(nzAux+6),intent(out)::ziOut
@@ -60,9 +62,9 @@
     double precision,dimension(2),intent(out)::LCV
     double precision::ca,cb,dd
     double precision,external::funcpassplines,funcpascpm,funcpasweib
-	double precision,external::funcpasgenweib,funcpasgenloglogistic,funcpasgenlognormal
-	double precision,external::funcpasgenadditif,funcpasgenadditif_tps,funcpasgenadditif_param,funcpasgenadditif_pen
-	double precision,external::funcpasgenadditif_alternatif,funcpasgenadditifalternatif_tps
+    double precision,external::funcpasgenweib,funcpasgenloglogistic,funcpasgenlognormal
+    double precision,external::funcpasgenadditif,funcpasgenadditif_tps,funcpasgenadditif_param,funcpasgenadditif_pen
+    double precision,external::funcpasgenadditif_alternatif,funcpasgenadditifalternatif_tps
     double precision,external::funcpascpm_intcens,funcpassplines_intcens,funcpasweib_intcens
     double precision,external::funcpassplines_log,funcpasweib_log,funcpascpm_log
     double precision,external::funcpas_tps
@@ -85,12 +87,11 @@
     double precision,dimension(0:100,0:4*sum(filtretps0))::BetaTpsMat ! matrice des effets depedants du temps (4 colonnes par effet dep du tps)
     double precision,dimension(nbinnerknots0+qorder0)::basis
     double precision,dimension(3),intent(inout)::EPS ! seuils de convergence
-	
-	integer::familyrisk
+    integer::familyrisk
 
 
-!call dblepr("Je suis dans la subroutine FRAILPENALGEN", -1, 0.d0, 1)
-!verification
+    !call dblepr("Je suis dans la subroutine FRAILPENALGEN", -1, 0.d0, 1)
+    !verification
     !print*,nsujetAux,ngAux,icenAux,nstAux,effetAux,nzAux,ax1,ax2,nvaAux
     !do i =1,5
     !    print*,i,tt0Aux(i),tt1Aux(i),ttUAux(i),icAux(i),groupeAux(i)
@@ -101,11 +102,11 @@
     !end do
     !STOP
 
-!cpm
+    !cpm
     istopp=0
     time = 0.d0
 
-!AD:add for new marq
+    !AD:add for new marq
     epsa=EPS(1) !1.d-4
     epsb=EPS(2) !1.d-4
     epsd=EPS(3) !1.d-4
@@ -551,8 +552,8 @@
     end if
 
     allocate(k0T(nst)) !k0T en plus strates A.Lafourcade 05/2014
-    allocate(H_hess(npmax,npmax),Hspl_hess(npmax,npmax), &
-    hess(npmax,npmax),I_hess(npmax,npmax))
+    allocate(H_hess(np,np),Hspl_hess(np,np), &
+    hess(np,np),I_hess(np,np))
 
     H_hess=0.d0
     I_hess=0.d0
@@ -957,17 +958,17 @@
                     call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpassplines_log)
                 endif
             else
-			    if (familyrisk.eq.0) then
-				    call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpas_tps)
-				endif
-			    if (familyrisk.eq.3) then
+                if (familyrisk.eq.0) then
+                    call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpas_tps)
+                endif
+                if (familyrisk.eq.3) then
                     !call dblepr("FRAILPENALGEN : appel marq98j_modadd et funcpasgenadditif_tps", -1, 0.d0, 1)
                     call marq98j_modadd(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpasgenadditif_tps)
-				endif
-				if (familyrisk.eq.4) then
+                endif
+                if (familyrisk.eq.4) then
                     !call dblepr("FRAILPENALGEN : appel marq98j et funcpasgenadditifalternatif_tps", -1, 0.d0, 1)
                     call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpasgenadditifalternatif_tps)
-				endif
+                endif
                 !call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpas_tps)
             endif
         case(1)
@@ -992,30 +993,30 @@
                     if (intcens.eq.1) then
                         call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpasweib_intcens)
                     else
-					    if (familyrisk.eq.0) then
+                        if (familyrisk.eq.0) then
                             !call dblepr("FRAILPENALGEN : appel marq98j et funcpasgenweib", -1, 0.d0, 1)
                             call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpasgenweib)
-						endif
-						if (familyrisk.eq.1) then
+                        endif
+                        if (familyrisk.eq.1) then
                             !call dblepr("FRAILPENALGEN : appel marq98j et funcpasgenloglogistic", -1, 0.d0, 1)
                             call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpasgenloglogistic)
-						endif
-						if (familyrisk.eq.2) then
+                        endif
+                        if (familyrisk.eq.2) then
                             !call dblepr("FRAILPENALGEN : appel marq98j et funcpasgenlognormal", -1, 0.d0, 1)
                             call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpasgenlognormal)
-						endif
-						if (familyrisk.eq.3) then
+                        endif
+                        if (familyrisk.eq.3) then
 						    !call dblepr("FRAILPENALGEN : appel marq98j_modadd et funcpasgenadditif_pen", -1, 0.d0, 1)
                             call marq98j_modadd(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpasgenadditif_pen)
                             !call dblepr("FRAILPENALGEN : appel marq98j et funcpasgenadditif", -1, 0.d0, 1)
                             !call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpasgenadditif)
 							!call dblepr("FRAILPENALGEN : appel marq98j et funcpasgenadditif_param", -1, 0.d0, 1)
 							!call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpasgenadditif_param)
-						endif
-						if (familyrisk.eq.4) then
+                        endif
+                        if (familyrisk.eq.4) then
                             !call dblepr("FRAILPENALGEN : appel marq98j et funcpasgenadditif_alternatif", -1, 0.d0, 1)
                             call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpasgenadditif_alternatif)
-						endif
+                        endif
                     endif
                 else
                     call marq98j(k0,b,np,ni,v,res,ier,istop,effet,ca,cb,dd,funcpasweib_log)
@@ -1042,22 +1043,14 @@
 
 
 !    j=(np-nva)*(np-nva+1)/2
-
-    call multis(I_hess,H_hess,np,np,np,IH)
-    call multis(H_hess,IH,np,np,np,HIH)
-
-!    if(effet.eq.1)then
-!        j=(np-nva)*(np-nva+1)/2
-    !    write(*,*)''
-    !    write(*,*)'variance non corrigee H pour theta:'
-    !    write(*,*)((2.d0*b(np-nva))**2)*H_hess(np-nva,np-nva)
-    !    write(*,*)'variance corrigee HIH pour theta:'
-    !    write(*,*)((2.d0*b(np-nva))**2)*HIH(np-nva,np-nva)
-!    endif
-
-!    if(effet.eq.1)then
-!        j=(np-nva)*(np-nva+1)/2
-!    endif
+    !call multis2(I_hess,H_hess,np,np,np,IH,np)
+    !call multis2(H_hess,IH,np,np,np,HIH,np)
+    allocate(HIH_temp(np,np),IH_temp(np,np))
+    call multis2(I_hess,H_hess,np,np,np,IH_temp,np)
+    call multis2(H_hess,IH_temp,np,np,np,HIH_temp,np)
+    IH=IH_temp 
+    HIH=HIH_temp
+    deallocate(HIH_temp,IH_temp)
 
     if(effet.eq.1.and.ier.eq.-1)then
         v((np-nva)*(np-nva+1)/2)=10.d10
@@ -1091,7 +1084,7 @@
             endif
             if (familyrisk.eq.2) then
                 Call distanceSlognormal(b,np,mt,xTOut,lamTOut,xSuT,suTOut)!en plus strates A.Laf 05/2014   
-            endif		
+            endif
     end select
 
     resOut=res
